"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.noTransWithoutPrettierIgnore = void 0;
const utils_1 = require("@typescript-eslint/utils");
const constants_1 = require("./constants");
const utils_2 = require("./utils");
const maybeReport = (node, context) => {
    const sourceCode = context.getSourceCode();
    const transComponent = (0, utils_2.getTransElement)(node);
    const isChecking = transComponent && !transComponent.openingElement.selfClosing;
    if (isChecking) {
        const mainParent = (0, utils_2.getParent)(transComponent);
        if (!mainParent) {
            return;
        }
        const report = () => {
            context.report({
                messageId: 'error',
                node: transComponent,
                fix(fixer) {
                    if (mainParent.type === utils_1.AST_NODE_TYPES.AssignmentPattern) {
                        return fixer.insertTextBefore(mainParent, constants_1.PRETTIER_IGNORE_CODE_INLINE);
                    }
                    if (utils_2.INLINE_NODE_TYPES.includes(mainParent.type)) {
                        return fixer.insertTextBefore(transComponent, constants_1.PRETTIER_IGNORE_CODE_INLINE);
                    }
                    if (utils_2.JSX_NODES.includes(mainParent.type)) {
                        return fixer.insertTextBeforeRange(transComponent.range, constants_1.PRETTIER_IGNORE_JSX_FIX);
                    }
                    if (mainParent.type === utils_1.AST_NODE_TYPES.ReturnStatement) {
                        return fixer.insertTextBefore(mainParent, constants_1.PRETTIER_IGNORE_CODE);
                    }
                    if (mainParent.type === utils_1.AST_NODE_TYPES.VariableDeclaration &&
                        mainParent.declarations.length > 1) {
                        const declarator = transComponent.parent;
                        return declarator
                            ? fixer.insertTextBefore(declarator, constants_1.PRETTIER_IGNORE_CODE_INLINE)
                            : null;
                    }
                    const code = sourceCode.getText(mainParent);
                    const newCode = `${constants_1.PRETTIER_IGNORE_CODE}${code}`;
                    return fixer.replaceTextRange(mainParent.range, newCode);
                }
            });
        };
        let { codePrettier } = (0, utils_2.getInfoPrettier)(mainParent, sourceCode);
        const checkWithPrettier = (code) => !constants_1.RegPrettierWithCode.test(code) && report();
        if (mainParent.type === utils_1.AST_NODE_TYPES.ReturnStatement) {
            if (!constants_1.RegPrettierForReturnStatement.test(codePrettier)) {
                report();
            }
            return;
        }
        if (mainParent.type === utils_1.AST_NODE_TYPES.AssignmentPattern) {
            const parentArgs = mainParent.parent;
            const index = parentArgs.params.findIndex((item) => item === mainParent);
            codePrettier = sourceCode.getText(parentArgs).split(',')[index];
            if (!constants_1.RegPrettierForArguments.test(codePrettier)) {
                report();
            }
            return;
        }
        if (utils_2.INLINE_NODE_TYPES.includes(mainParent.type)) {
            codePrettier = sourceCode.getText(mainParent);
            if (mainParent.type === utils_1.AST_NODE_TYPES.ArrayExpression) {
                const index = mainParent.elements.findIndex((item) => item === transComponent);
                codePrettier = sourceCode.getText(mainParent).split(',')[index];
            }
            if (!constants_1.RegPrettierForInline.test(codePrettier)) {
                report();
            }
            return;
        }
        if (utils_2.JSX_NODES.includes(mainParent.type)) {
            codePrettier = (0, utils_2.getInfoPrettier)(transComponent, sourceCode).codePrettier;
        }
        checkWithPrettier(codePrettier);
    }
};
const creator = utils_1.ESLintUtils.RuleCreator(() => 'https://github.com/whydidoo/eslint-plugin-react-i18next-prettier-ignore#readme');
exports.noTransWithoutPrettierIgnore = creator({
    create(context) {
        const nodes = new Set();
        return {
            "JSXOpeningElement > JSXIdentifier[name='Trans']": (node) => {
                nodes.add(node);
            },
            'Program:exit': () => {
                nodes.forEach((node) => {
                    maybeReport(node, context);
                });
                nodes.clear();
            }
        };
    },
    name: 'no-trans-without-prettier-ignore',
    meta: {
        messages: {
            error: '<Trans /> component is not prepended by /* prettier-ignore */.\n\nPlease, add {/* prettier-ignore */} or /* prettier-ignore */ in before. Missing /* prettier-ignore */ may affect the i18n strings when prettier changes the formatting of this layout code'
        },
        fixable: 'code',
        type: 'suggestion',
        schema: [],
        docs: {
            description: '<Trans /> usage without /* prettier-ignore */ before it is not allowed',
            recommended: 'error'
        }
    },
    defaultOptions: []
});
