"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.JSX_NODES = exports.INLINE_NODE_TYPES = exports.getInfoPrettier = exports.getParent = exports.getTransElement = void 0;
const utils_1 = require("@typescript-eslint/utils");
const getTransElement = (node) => {
    const nodeType = node.type;
    const nodeParent = node.parent;
    if (!nodeParent)
        return null;
    if (nodeType === utils_1.AST_NODE_TYPES.JSXIdentifier ||
        nodeType === utils_1.AST_NODE_TYPES.JSXOpeningElement) {
        const parent = nodeParent;
        return (0, exports.getTransElement)(parent);
    }
    return node;
};
exports.getTransElement = getTransElement;
const getParent = (node) => {
    const nextNode = node.parent;
    if (!nextNode) {
        return null;
    }
    switch (nextNode.type) {
        case utils_1.AST_NODE_TYPES.VariableDeclarator:
        case utils_1.AST_NODE_TYPES.ArrowFunctionExpression: {
            return (0, exports.getParent)(nextNode);
        }
        default:
            return nextNode;
    }
};
exports.getParent = getParent;
const getInfoPrettier = (node, sourceCode) => {
    const startLine = node.loc.start.line - 1;
    const endLine = node.loc.end.line;
    const linePrettier = startLine !== 0 ? startLine - 1 : startLine;
    const codePrettier = String(sourceCode.lines.slice(linePrettier, endLine).join('\n'));
    return {
        startLine,
        endLine,
        linePrettier,
        codePrettier
    };
};
exports.getInfoPrettier = getInfoPrettier;
exports.INLINE_NODE_TYPES = [
    utils_1.AST_NODE_TYPES.ConditionalExpression,
    utils_1.AST_NODE_TYPES.LogicalExpression,
    utils_1.AST_NODE_TYPES.ArrayExpression,
    utils_1.AST_NODE_TYPES.JSXExpressionContainer
];
exports.JSX_NODES = [
    utils_1.AST_NODE_TYPES.JSXElement,
    utils_1.AST_NODE_TYPES.JSXFragment
];
